%% 
%% CS Blank Signature Page Document Class
%%
%% It is based on the standard LaTeX report class.
%% 
%% 
%% This file is part of the LaTeX2e system. 
%% ---------------------------------------- 
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{csblanksigco}[2007/11/06 CS Dept. Kent State University]
\newcommand\docsize{}  % to allow 10pt or 11pt to be specified as option
\DeclareOption{10pt}{\renewcommand\docsize{10pt}}
\DeclareOption{11pt}{\renewcommand\docsize{11pt}}
\DeclareOption{12pt}{\renewcommand\docsize{12pt}}
%  Prepare to load the standard report class (12pt):
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ExecuteOptions{12pt}         % define 11pt as the default doc size
\ProcessOptions
\LoadClass[\docsize]{report}  % load report.cls

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PAGE LAYOUT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SIDE MARGINS:
% Values for one-sided printing:
\oddsidemargin 0.25in  

\textwidth 6.25in            % width of text
 
% VERTICAL SPACING:
                          % Top of page:
\headheight 0.25in         %    Height of box containing running head.
\headsep 0.25in            %    Space between running head and text.
\textheight 9.0in        %    space for text
\footskip 0.25in           %    Distance from baseline of box containing foot
                         %    to baseline of last line of text.

\brokenpenalty=10000
% double space the text
\renewcommand{\baselinestretch}{2}

\makeatletter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% variables that must be provided
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\degrees#1{\gdef\@degrees{#1}}
\def\@degrees{}
\def\@author{}
\def\@dept{Computer Science \vspace*{.5 \baselineskip}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Signature page (blank)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\signaturepageold{
	\begin{center}
		\vspace*{30pt}
		\vbox to144pt{
			Thesis written by \\
			\@author \\
                        \@degrees \\
                        \vfill
		}
		\vfill
		Approved by \\[12pt]
		\_\hrulefill\ , \makebox[73mm][l]{Advisor} \\
                \_\hrulefill\ , \parbox[t]{73mm}{\raggedright Chair, Department of \@dept}  \\[12pt]
                \_\hrulefill\ , \makebox[73mm][l]{Dean, College of Arts and Sciences}
	\end{center}
}
\def\signaturepage{
	\begin{center}
		\vspace*{30pt}
		\vbox to144pt{
			Dissertation written by \\
			\@author \\
                        \@degrees \\
                        \vfill
		}
		\vfill
		Approved by \\[8pt]
		\_\hrulefill\ , \makebox[78mm][l]{Co-Chair, Doctoral Dissertation Committee} \\
		\_\hrulefill\ , \makebox[78mm][l]{Co-Chair} \\
		\_\hrulefill\ , \makebox[78mm][l]{Members, Doctoral Dissertation Committee} \\
		\_\hrulefill\ ~ \makebox[78mm]{\ } \\
		\_\hrulefill\ ~ \makebox[78mm]{\ } \\
		\_\hrulefill\ ~ \makebox[78mm]{\ } \\[8pt]
		Accepted by \\[8pt]
                %\vspace*{\baselineskip}
		\_\hrulefill\ , \parbox[t]{78mm}{\raggedright Chair, Department of \@dept}  \\[8pt] 
		\_\hrulefill\ , \makebox[78mm][l]{Dean, College of Arts and Sciences}
        \end{center}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Blank page to force the number ii on signature page
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\blankpage{
   \begin{center}
    \vspace*{4.0in}
    Page intentionally blank
   \end{center}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Front Matter
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\frontmatter{
        \pagenumbering{roman}
	\pagestyle{plain}
        \blankpage
        \newpage\newpage
        \signaturepage
}

\makeatother